import numpy as np

class agg:
    
    # Initialize the class correctly
    def __init__(self, ls =[]):
        self.ls = ls
    
    # Return the max value in the list
    def return_max(self):
        return max(self.ls)
    
    # Return the min value in the list
    def return_min(self):
        return min(self.ls)
    
    # Return the max value squared
    def return_max_squared(self):
        return (max(self.ls))**2
    
    # Return length of the list
    def return_length(self):
        return len(self.ls)
    
    # Return the sum of all positive numbers only 
    def return_positive_sum(self):
        sum = 0
        for i in range(len(self.ls)):
            if self.ls[i] > 0:
                sum = sum + self.ls[i]
        return sum
    
    # Return the count of all negative numbers
    def return_negative_count(self):
        cnt = 0
        for i in range(len(self.ls)):
            if self.ls[i] < 0:
                cnt = cnt + 1
        return cnt
    
    # Average
    def avg(self):
        sum = 0
        for i in range(len(self.ls)):
            sum = sum + self.ls[i]
        return sum/len(self.ls)
    
    # Median
    def median(self):
        return np.median(self.ls)
        


import setuptools

# Loads your README
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="abdurion", # Replace with your own username
    version="0.0.7", # Your version number, needs to be incremented with each iteration
    author="Abdulrahman AlQumaidy", # Your name
    author_email="author@example.com", # Your email
    description="A small example package", # A one sentence description of your package
    long_description=long_description, # A longer description from your `README.md`
    long_description_content_type="text/markdown", # The format of you long_description file
    url="https://github.com/abdurion", # GitHub where to find your code
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ], # Additional required pieces of metadata (Don't Change)
    packages=setuptools.find_packages(), # Find all packages used and get them ready for distribution (Dont Change)
    python_requires=">=3.7", # The required version of python
)